@charset "utf-8";
/*
 * このファイルを編集して、profile-directory/chrome/userContent.css
 * としてコピーしてください。
 */

/*
 * このファイルは、表示するすべての Web ページにスタイルを適用するのに使用
 * することができます。
 * !important なし規定は、Web ページ作者が何かを設定した場合には、作者の
 * 規定で無効になります。!important ありの規定は、Web ページ作者の規定を
 * 無効にします。
 */

/*
 * 例: "blink" 要素の点滅を無効にする
 *
 * blink { text-decoration: none ! important; }
 *
 */

/*
 * 例: すべてのテーブルに 2 ピクセルの幅を強制する
 *
 * table { border: 2px solid; }
 */

/*
 * 例: "marquee" 要素を無効にする
 *
 * marquee { -moz-binding: none; }
 *
 */
 
/*
 * さらに多くの事例は、 http://www.mozilla.org/unix/customizing.html
 * を参照してください。
 */

